@@ -55,6 +55,7 @@ import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.ArrayUtils;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Interests;
@@ -83,6 +84,8 @@ public class ClientConfig {
     final private static String CONFIGITEM_SUPPORTED_TYPES = "com.openexchange.documentconverter.client.supportedTypes";
     final private static String CONFIGITEM_PDFEXTRACTOR_INSTALL_DIR = "com.openexchange.documentconverter.client.pdfextractor.installDir";
     final private static String CONFIGITEM_PDFEXTRACTOR_WORK_DIR ="com.openexchange.documentconverter.client.pdfextractor.workDir";
+    final private static String CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS = "com.openexchange.documentconverter.client.autoCleanupTimeoutSeconds";
+
 
     /**
      * All config items
@@ -93,7 +96,8 @@ public class ClientConfig {
         CONFIGITEM_ENABLE_CACHE_LOOKUP,
         CONFIGITEM_SUPPORTED_TYPES,
         CONFIGITEM_PDFEXTRACTOR_INSTALL_DIR,
-        CONFIGITEM_PDFEXTRACTOR_WORK_DIR
+        CONFIGITEM_PDFEXTRACTOR_WORK_DIR,
+        CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS
     };
 
     /**
@@ -108,7 +112,7 @@ public class ClientConfig {
      */
     public final static String PDFEXTRACTOR_EXECUTABLE_FILENAME_1 = "pdftool";
     public final static String PDFEXTRACTOR_EXECUTABLE_FILENAME_2 = "pdf2svg";
-    public final static String PDFEXTRACTOR_EXECUTABLE_WORKDIR_NAME = "oxpdfextractor";
+    public final static String PDFEXTRACTOR_EXECUTABLE_WORKDIR_NAME = "oxdcc.tmp";
 
     /**
      * Initializes a new {@link ClientConfig}.
@@ -123,7 +127,7 @@ public class ClientConfig {
      */
     public void reloadConfiguration(ConfigurationService configService) {
         if (DocumentConverterManager.isLogTrace()) {
-            DocumentConverterManager.logTrace("DC is reloading config items: " + Arrays.toString(RELOADABLE_CONFIGITEMS));
+            DocumentConverterManager.logTrace("DC client is reloading config items: " + Arrays.toString(RELOADABLE_CONFIGITEMS));
         }
 
         implReadConfig(configService, RELOADABLE_CONFIGITEMS);
@@ -172,6 +176,12 @@ public class ClientConfig {
      */
     public File PDFEXTRACTOR_EXECUTABLE_PATH = new File("/opt/open-xchange/sbin", PDFEXTRACTOR_EXECUTABLE_FILENAME_1);
 
+    /**
+     * The auto cleanup time in milliseconds after which
+     * a stateful conversion is terminated
+     */
+    public int AUTO_CLEANUP_TIMEOUT_MILLIS = 0;
+
     // - Internally used properties --------------------------------------------
 
     /**
@@ -214,12 +224,12 @@ public class ClientConfig {
                         REMOTEURL_DOCUMENTCONVERTER = new URL(curStringEntry);
                     }
                 } catch (final Exception e) {
-                    DocumentConverterManager.logError("DC com.openexchange.documentconverter.client.remoteDocumentConverterUrl is not a valid http URL: " + curStringEntry + " => Remote document conversion disabled!: " + e.getMessage());
+                    DocumentConverterManager.logError("DC client com.openexchange.documentconverter.client.remoteDocumentConverterUrl is not a valid http URL: " + curStringEntry + " => Remote document conversion disabled!: " + e.getMessage());
                 }
             }
 
             if (null == REMOTEURL_DOCUMENTCONVERTER) {
-                DocumentConverterManager.logError("DC com.openexchange.documentconverter.client.remoteDocumentConverterUrl is not set at all => Documentconverter functionality will not be available!");
+                DocumentConverterManager.logError("DC client com.openexchange.documentconverter.client.remoteDocumentConverterUrl is not set at all => Documentconverter functionality will not be available!");
             }
         }
 
@@ -258,7 +268,7 @@ public class ClientConfig {
 
                 PDFEXTRACTOR_EXECUTABLE_PATH = pdfExtractorExecutable;
             } else {
-                DocumentConverterManager.logError("DC PDF extraction tool cannot be executed in path: " +
+                DocumentConverterManager.logError("DC client PDF extraction tool cannot be executed in path: " +
                     pdfExtractorExecutable.getParent() +
                     " => PDF Page extraction will be disabled!");
             }
@@ -270,10 +280,12 @@ public class ClientConfig {
 
             final File pdfExtractorWorkDir = new File(curStringEntry, PDFEXTRACTOR_EXECUTABLE_WORKDIR_NAME);
 
+            FileUtils.deleteQuietly(pdfExtractorWorkDir);
+
             if (DocumentConverterManager.mkdirs(pdfExtractorWorkDir)) {
                 PDFEXTRACTOR_WORKDIR = pdfExtractorWorkDir;
             } else {
-                DocumentConverterManager.logError("DC PDF extraction tool working directoy cannot be created or is not writable: " +
+                DocumentConverterManager.logError("DC client PDF extraction tool working directoy cannot be created or is not writable: " +
                     pdfExtractorWorkDir.getPath() +
                     " => PDF Page extraction will be disabled!");
 
@@ -282,6 +294,13 @@ public class ClientConfig {
             }
         }
 
+        // CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS
+        if (itemsToRead.contains(CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS) &&
+            (curIntEntry = configService.getIntProperty(CONFIGITEM_AUTO_CLEANUP_TIMEOUT_SECONDS, emptyInt)) != emptyInt) {
+
+            AUTO_CLEANUP_TIMEOUT_MILLIS = Math.max(curIntEntry, 0) * 1000;
+        }
+
         // - Internally used config items ----------------------------------
 
         // ENGINE_LOGFILE
