@@ -49,6 +49,7 @@
 
 package com.openexchange.documentconverter.client.impl;
 
+import java.io.IOException;
 import java.io.InputStream;
 import java.util.HashMap;
 import com.openexchange.config.ConfigurationService;
@@ -59,7 +60,7 @@ import com.openexchange.documentconverter.DocumentConverterManager;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.Nullable;
-import com.openexchange.documentconverter.ServerType;
+import com.openexchange.documentconverter.PDFExtractor;
 import com.openexchange.documentconverter.SingletonService;
 import com.openexchange.server.ServiceLookup;
 
@@ -97,16 +98,22 @@ public class ClientManager extends DocumentConverterManager implements IDocument
      * Initializes a new {@link ClientManager}.
      */
     private ClientManager(@NonNull final ServiceLookup services, @NonNull final ClientConfig clientConfig) {
-        super();
+        super(clientConfig.PDFEXTRACTOR_WORKDIR);
 
         m_services = services;
         m_clientConfig = clientConfig;
         m_asyncExecutor = new AsyncExecutor(this, this, ASYNC_CONVERTER_THREADCOUNT);
         m_remoteValidator = new RemoteValidator(m_clientConfig.REMOTEURL_DOCUMENTCONVERTER);
 
+        try {
+            m_pdfExtractor = new PDFExtractor(this, m_clientConfig.PDFEXTRACTOR_EXECUTABLE_PATH);
+        } catch (IOException e) {
+            logError("DC client PDFExtractor could not be initiaized correctly: " + m_clientConfig.PDFEXTRACTOR_EXECUTABLE_PATH);
+        }
+
         // check for invalid remote URL
         if ((null == m_clientConfig.REMOTEURL_DOCUMENTCONVERTER) || (m_clientConfig.REMOTEURL_DOCUMENTCONVERTER.toString().length() <= 0)) {
-            logError("DC remoteDocumentConverterUrl property is empty or not set at all. Client is not able to perform conversions until a valid Url is set!");
+            logError("DC client remoteDocumentConverterUrl property is empty or not set at all. Client is not able to perform conversions until a valid Url is set!");
         }
     }
 
@@ -122,7 +129,7 @@ public class ClientManager extends DocumentConverterManager implements IDocument
 
             // check for invalid remote URL
             if ((null == m_clientConfig.REMOTEURL_DOCUMENTCONVERTER) || (m_clientConfig.REMOTEURL_DOCUMENTCONVERTER.toString().length() <= 0)) {
-                logError("DC remoteDocumentConverterUrl property is empty or not set at all. Client is not able to perform conversions until a valid Url is set!");
+                logError("DC client remoteDocumentConverterUrl property is empty or not set at all. Client is not able to perform conversions until a valid Url is set!");
             }
         }
     }
@@ -149,35 +156,33 @@ public class ClientManager extends DocumentConverterManager implements IDocument
      * @see com.openexchange.documentconverter.IClientManager#beginPageConversion(java.lang.String, java.util.HashMap, java.util.HashMap)
      */
     @Override
+    @Deprecated
     public String beginPageConversion(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
-        return (new ManagedClientHashJob(this, m_clientConfig.REMOTEURL_DOCUMENTCONVERTER)).beginPageConversion(jobType, jobProperties, resultProperties);
+        DocumentConverterManager.logError("ManagedClientJob#beginPageConversion is deprecated and must not be called anymore! Use #convert to PDF and PDFExtractor instead.");
+        return null;
     }
 
     /* (non-Javadoc)
      * @see com.openexchange.documentconverter.IClientManager#getConversionPage(java.lang.String, int, java.util.HashMap, java.util.HashMap)
      */
     @Override
+    @Deprecated
     public InputStream getConversionPage(String jobIdStr, int pageNumber, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
-        return (new ManagedClientHashJob(this, m_clientConfig.REMOTEURL_DOCUMENTCONVERTER)).getConversionPage(jobIdStr, pageNumber, jobProperties, resultProperties);
+        DocumentConverterManager.logError("ManagedClientJob#getConversionPage is deprecated and must not be called anymore! Use #convert to PDF and PDFExtractor instead.");
+        return null;
     }
 
     /* (non-Javadoc)
      * @see com.openexchange.documentconverter.IClientManager#endPageConversion(java.lang.String, java.util.HashMap, java.util.HashMap)
      */
     @Override
+    @Deprecated
     public void endPageConversion(String jobIdStr, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
-        (new ManagedClientHashJob(this, m_clientConfig.REMOTEURL_DOCUMENTCONVERTER)).endPageConversion(jobIdStr, jobProperties, resultProperties);
+        DocumentConverterManager.logError("ManagedClientJob#endPageConversion is deprecated and must not be called anymore! Use #convert to PDF and PDFExtractor instead.");
     }
 
     // - Implementation --------------------------------------------------------
 
-    /**
-     * @return
-     */
-    public boolean hasRemoteServer(ServerType serverType) {
-        return (null != m_remoteValidator);
-    }
-
     /**
      * @return
      */
@@ -226,6 +231,12 @@ public class ClientManager extends DocumentConverterManager implements IDocument
         return m_clientConfig;
     }
 
+    // - PDFExtractor ----------------------------------------------------------
+
+    public PDFExtractor getPDFExtractor() {
+        return m_pdfExtractor;
+    }
+
     // - Statics ---------------------------------------------------------------
 
     final private static int ASYNC_CONVERTER_THREADCOUNT = 3;
@@ -241,4 +252,6 @@ public class ClientManager extends DocumentConverterManager implements IDocument
     final private ServiceLookup m_services;
 
     final private AsyncExecutor m_asyncExecutor;
+
+    private PDFExtractor m_pdfExtractor;
 }
