@@ -57,6 +57,7 @@ import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang.StringUtils;
 import com.openexchange.documentconverter.DocumentConverterManager;
 import com.openexchange.documentconverter.LogData;
+import com.openexchange.documentconverter.MutableWrapper;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.Properties;
 
@@ -85,8 +86,8 @@ public class ManagedClientHashJob extends ManagedClientJob {
         // we may need to call two subsequent conversions with job
         // properties, that are read more than once, which is problematic
         // in case of an InputStream based source content property
-        final boolean[] deleteInputFileProperty = { false };
-        final HashMap<String, Object> fileBasedJobProperties = createFileBasedJobProperties(jobProperties, deleteInputFileProperty);
+        final MutableWrapper<Boolean> deleteInputFile = new MutableWrapper<Boolean>(Boolean.FALSE);
+        final HashMap<String, Object> fileBasedJobProperties = createFileBasedJobProperties(jobProperties, deleteInputFile);
         InputStream ret = null;
 
         if ((null != jobType) && (null != fileBasedJobProperties)) {
@@ -100,7 +101,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
 
             if (trace) {
                 traceStartTimeMillis = System.currentTimeMillis();
-                DocumentConverterManager.logTrace("DC received request for " + (isAsyncRequest ? "async " : "") + "conversion", fileBasedJobProperties);
+                DocumentConverterManager.logTrace("DC client received request for " + (isAsyncRequest ? "async " : "") + "conversion", fileBasedJobProperties);
             }
 
             // try to get a valid result from a remotehash request first
@@ -113,7 +114,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
 
                 if (queryResultAvailability) {
                     if (trace) {
-                        DocumentConverterManager.logTrace("DC remotehash client query for asynchronous request initiated",
+                        DocumentConverterManager.logTrace("DC client remotehash client query for asynchronous request initiated",
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"));
                     }
@@ -121,14 +122,14 @@ public class ManagedClientHashJob extends ManagedClientJob {
                     queryResultAvailability = super.queryAvailability(jobType, hashedJobProperties, resultProperties);
 
                     if (trace) {
-                        DocumentConverterManager.logTrace("DC remotehash client query for asynchronous request " + (queryResultAvailability ? "succeeded" : "failed"),
+                        DocumentConverterManager.logTrace("DC client remotehash client query for asynchronous request " + (queryResultAvailability ? "succeeded" : "failed"),
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"),
                             new LogData("exectime", Long.toString(System.currentTimeMillis() - traceStartTimeMillis) + "ms"));
                     }
                 } else {
                     if (trace) {
-                        DocumentConverterManager.logTrace("DC remotehash client request initiated",
+                        DocumentConverterManager.logTrace("DC client remotehash client request initiated",
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"));
                     }
@@ -136,7 +137,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
                     ret = super.process(jobType, hashedJobProperties, resultProperties);
 
                     if (trace) {
-                        DocumentConverterManager.logTrace("DC remotehash client request " + ((null != ret) ? "succeeded" : "failed"),
+                        DocumentConverterManager.logTrace("DC client remotehash client request " + ((null != ret) ? "succeeded" : "failed"),
                             new LogData("remotehash", remoteCacheHash),
                             new LogData("filename", (null != infoFileName) ? infoFileName : "unkown"),
                             new LogData("exectime", Long.toString(System.currentTimeMillis() - traceStartTimeMillis) + "ms"));
@@ -158,7 +159,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
             }
         }
 
-        if ((null != fileBasedJobProperties) && deleteInputFileProperty[0]) {
+        if ((null != fileBasedJobProperties) && deleteInputFile.get().booleanValue()) {
             FileUtils.deleteQuietly((File) fileBasedJobProperties.get(Properties.PROP_INPUT_FILE));
         }
 
@@ -213,7 +214,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
      * @param jobInputFile
      * @return
      */
-    static StringBuilder getPseudoHashBuilder(@NonNull String jobType, @NonNull HashMap<String, Object> jobProperties, @NonNull File jobInputFile) {
+    StringBuilder getPseudoHashBuilder(@NonNull String jobType, @NonNull HashMap<String, Object> jobProperties, @NonNull File jobInputFile) {
         StringBuilder pseudoHashBuilder = null;
 
         switch  (jobType) {
@@ -257,7 +258,7 @@ public class ManagedClientHashJob extends ManagedClientJob {
                 pseudoHashBuilder = (new StringBuilder(Properties.REMOTECACHE_VERSION_PREFIX)).append(getDefaultPseudoHashBuilder("p2g", jobProperties, jobInputFile));
 
                 // job type and target image mime type
-                pseudoHashBuilder.append(resultMimeType.equals("image/jpeg") ? "jpg" : "png");
+                pseudoHashBuilder.append("image/jpeg".equals(resultMimeType) ? "jpg" : "png");
 
                 // autoscale
                 if ((null != autoscale) && autoscale.booleanValue()) {
@@ -298,17 +299,17 @@ public class ManagedClientHashJob extends ManagedClientJob {
      * @param jobInputFile
      * @return
      */
-    static StringBuilder getDefaultPseudoHashBuilder(@NonNull String jobType, @NonNull HashMap<String, Object> jobProperties, @NonNull File jobInputFile) {
+    StringBuilder getDefaultPseudoHashBuilder(@NonNull String jobType, @NonNull HashMap<String, Object> jobProperties, @NonNull File jobInputFile) {
         return DocumentConverterManager.getFileHashBuilder(jobInputFile, (String) jobProperties.get(Properties.PROP_LOCALE)).append(jobType);
     }
 
     /**
      * @param jobProperties
-     * @param deleteInputFileProperty
+     * @param deleteInputFile
      * @return
      */
-    static HashMap<String, Object> createFileBasedJobProperties(HashMap<String, Object> jobProperties, boolean[] deleteInputFileProperty) {
-        final File jobInputFile = DocumentConverterManager.getJobInputFile(jobProperties, deleteInputFileProperty);
+    HashMap<String, Object> createFileBasedJobProperties(HashMap<String, Object> jobProperties, MutableWrapper<Boolean> deleteInputFile) {
+        final File jobInputFile = m_clientManager.getJobInputFile(jobProperties, deleteInputFile);
         HashMap<String, Object> fileBasedJobProperties = null;
 
         // ensure, that we always have a file based job property set to work on
