@@ -77,7 +77,6 @@ import org.json.JSONTokener;
 import com.openexchange.documentconverter.DocumentConverterManager;
 import com.openexchange.documentconverter.DocumentInformation;
 import com.openexchange.documentconverter.HttpHelper;
-import com.openexchange.documentconverter.HttpResponseProcessor;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
 import com.openexchange.documentconverter.LogData;
@@ -113,11 +112,11 @@ class ManagedClientJob {
     boolean queryAvailability(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
         boolean ret = false;
 
-        if (checkJobPreconditions(jobProperties, resultProperties, 1)) {
-            if (prepareRemoteCall(jobProperties, RCALL_QUERY_AVAILABILITY)) {
+        if (implCheckJobPreconditions(jobProperties, resultProperties, 1)) {
+            if (implPrepareRemoteCall(jobProperties, RCALL_QUERY_AVAILABILITY)) {
                 jobProperties.put(Properties.PROP_JOBTYPE, jobType);
 
-                doRemoteCall(jobProperties, resultProperties);
+                implDoRemoteCall(jobProperties, resultProperties);
 
                 ret = resultProperties.containsKey(Properties.PROP_RESULT_ERROR_CODE) &&
                     (JobError.NONE == JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)));
@@ -127,108 +126,40 @@ class ManagedClientJob {
         return ret;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.documentconverter.impl.ManagedJob#convert(java.lang.String, java.util.HashMap, java.util.HashMap)
+    /**
+     * @param jobType
+     * @param jobProperties
+     * @param resultProperties
+     * @return
      */
     InputStream process(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
         InputStream ret = null;
         final Boolean asyncObject = (Boolean) jobProperties.get(Properties.PROP_ASYNC);
 
         if ((null != asyncObject) && asyncObject.booleanValue()) {
-            if (checkJobInputFileSize(jobProperties, resultProperties) &&
-                checkSupportedJobInputType(jobProperties, resultProperties)) {
+            if (implCheckJobInputFileSize(jobProperties, resultProperties) &&
+                implCheckSupportedJobInputType(jobProperties, resultProperties)) {
 
                 m_clientManager.triggerAsyncConvert(jobType, jobProperties, resultProperties);
             }
-        } else if (checkJobPreconditions(jobProperties, resultProperties, 1)) {
-            if (prepareRemoteCall(jobProperties, RCALL_CONVERT)) {
+        } else if (implCheckJobPreconditions(jobProperties, resultProperties, 1)) {
+            if (implPrepareRemoteCall(jobProperties, RCALL_CONVERT)) {
                 jobProperties.put(Properties.PROP_JOBTYPE, jobType);
-                ret = (InputStream) doRemoteCall(jobProperties, resultProperties);
+                ret = (InputStream) implDoRemoteCall(jobProperties, resultProperties);
             }
         }
 
         return ret;
     }
 
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.documentconverter.impl.ManagedJob#beginPageConversion(java.lang.String, java.util.HashMap, java.util.HashMap)
-     */
-    String beginPageConversion(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
-        String ret = null;
-
-        if (checkJobPreconditions(jobProperties, resultProperties, 2)) {
-            // check if a remote conversion is requested and if we're not called remotely by ourselves
-            if (prepareRemoteCall(jobProperties, RCALL_BEGINPAGECONVERSION)) {
-                jobProperties.put(Properties.PROP_JOBTYPE, jobType);
-                doRemoteCall(jobProperties, resultProperties);
-                ret = (String) resultProperties.get(Properties.PROP_RESULT_JOBID);
-
-                // save cookie for begin of stateful call in global cookie map, if possible
-                final String converterJobId = (String) resultProperties.get(Properties.PROP_RESULT_JOBID);
-                final String converterCookie = (String) resultProperties.get(Properties.PROP_RESULT_CONVERTER_COOKIE);
-
-                if (StringUtils.isNotEmpty(converterJobId) && StringUtils.isNotEmpty(converterCookie)) {
-                    m_converterCookieMap.put(converterJobId, converterCookie);
-                }
-            }
-        }
-
-        return ret;
-    }
-
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.documentconverter.impl.ManagedJob#getConversionPage(java.lang.String, int, java.util.HashMap)
-     */
-    InputStream getConversionPage(String jobIdStr, int pageNumber, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
-        InputStream ret = null;
-
-        if (checkJobPreconditions(jobProperties, resultProperties, 2)) {
-            jobProperties.put(Properties.PROP_JOBID, jobIdStr);
-            jobProperties.put(Properties.PROP_PAGE_NUMBER, Integer.valueOf(pageNumber));
-
-            // check if a remote conversion is requested and if we're not called remotely by ourselves;
-            // also add a possibly stored cookie for this job id to current job properties
-            if (prepareRemoteCall(jobProperties, RCALL_GETCONVERSIONPAGE)) {
-                ret = (InputStream) doRemoteCall(jobProperties, resultProperties);
-            }
-        }
-
-        return ret;
-    }
-
-    /*
-     * (non-Javadoc)
-     * @see com.openexchange.documentconverter.impl.ManagedJob#endPageConversion(java.lang.String)
-     */
-    void endPageConversion(String jobIdStr, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties) {
-        if (checkJobPreconditions(jobProperties, resultProperties, 2)) {
-            jobProperties.put(Properties.PROP_JOBID, jobIdStr);
-
-            // check if a remote conversion is requested and if we're not called remotely by ourselves
-            if (prepareRemoteCall(jobProperties, RCALL_ENDPAGECONVERSION)) {
-                doRemoteCall(jobProperties, resultProperties);
-
-                // delete cookie for end of stateful call from global cookie map, if possible
-                final String converterJobId = (String) resultProperties.get(Properties.PROP_RESULT_JOBID);
-
-                if (StringUtils.isNotEmpty(converterJobId)) {
-                    m_converterCookieMap.remove(converterJobId);
-                }
-            }
-        }
-    }
-
-    // - Protected Methodds ----------------------------------------------------
+    // - Implementation --------------------------------------------------------
 
     /**
      * @param jobProperties
      * @param resultProperties
      * @return
      */
-    static protected byte[] getInputBuffer(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
+    private byte[] implGetInputBuffer(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
         byte[] ret = null;
 
         try (final InputStream inputStm = (jobProperties.containsKey(Properties.PROP_INPUT_FILE) ?
@@ -243,15 +174,13 @@ class ManagedClientJob {
         }
 
         // check, if length of byte array is larger than specified config source file size
-        if ((null != ret) && (setSourceFileSizeError(ret.length, jobProperties, resultProperties))) {
+        if ((null != ret) && (implSetSourceFileSizeError(ret.length, jobProperties, resultProperties))) {
             ret = null;
         }
 
         return ret;
     }
 
-    // - Implementation --------------------------------------------------------
-
     /**
      * @param jobProperties
      */
@@ -261,14 +190,14 @@ class ManagedClientJob {
      * @param minRemoteAPIVersion
      * @return true, if job processing can proceed
      */
-    protected boolean checkJobPreconditions(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties, int minRemoteAPIVersion) {
+    private boolean implCheckJobPreconditions(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties, int minRemoteAPIVersion) {
         boolean ret = false;
 
         if (null != jobProperties) {
             // job is valid by default, if job properties exists at all
             // and source file size fits into the given constraints
-            ret = checkJobInputFileSize(jobProperties, resultProperties) &&
-                checkSupportedJobInputType(jobProperties, resultProperties);
+            ret = implCheckJobInputFileSize(jobProperties, resultProperties) &&
+                implCheckSupportedJobInputType(jobProperties, resultProperties);
         } else {
             resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.GENERAL.errorCode()));
         }
@@ -286,7 +215,7 @@ class ManagedClientJob {
      * @return true, if source file size is unlimited or below/equal
      *  to the given maximum source file size
      */
-    protected static boolean checkJobInputFileSize(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
+    private boolean implCheckJobInputFileSize(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
         boolean ret = false;
 
         if (null != jobProperties) {
@@ -295,7 +224,7 @@ class ManagedClientJob {
 
             if (null != inputFile) {
                 // check maxSourceFile
-                ret = !setSourceFileSizeError(inputFile.length(), jobProperties, resultProperties);
+                ret = !implSetSourceFileSizeError(inputFile.length(), jobProperties, resultProperties);
             } else {
                 // job is valid by default, if job properties exists
                 // at all and source file is given as input stream
@@ -314,7 +243,7 @@ class ManagedClientJob {
      * @return true, if source file size is unlimited or below/equal
      *  to the given maximum source file size
      */
-    protected static boolean checkSupportedJobInputType(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
+    private boolean implCheckSupportedJobInputType(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
         boolean ret = false;
 
         if (null != jobProperties) {
@@ -337,7 +266,7 @@ class ManagedClientJob {
                 inputType = "bin";
             }
 
-            ret = !setSupportedTypeError(inputType, jobProperties, resultProperties);
+            ret = !implSetSupportedTypeError(inputType, jobProperties, resultProperties);
         }
 
         return ret;
@@ -349,8 +278,8 @@ class ManagedClientJob {
      * @param resultProperties
      * @return true, if source size is larger than max size
      */
-    protected static boolean setSourceFileSizeError(long sourceSize, final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
-        final long maxSize = ClientManager.get().getClientConfig().MAX_DOCUMENT_SOURCEFILESIZE;
+    private boolean implSetSourceFileSizeError(long sourceSize, final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
+        final long maxSize = m_clientManager.getClientConfig().MAX_DOCUMENT_SOURCEFILESIZE;
         boolean ret = false;
 
         if (sourceSize > maxSize) {
@@ -360,7 +289,7 @@ class ManagedClientJob {
                 resultProperties.put(Properties.PROP_RESULT_ERROR_CODE, Integer.valueOf(JobError.MAX_SOURCESIZE.errorCode()));
 
                 if (DocumentConverterManager.isLogError()) {
-                    DocumentConverterManager.logError("DC detected source file size larger than configured size",
+                    DocumentConverterManager.logError("DC client detected source file size larger than configured size",
                         jobProperties,
                         new LogData("sourcesize", (new Long(sourceSize)).toString()),
                         new LogData("maxsize", (new Long(maxSize)).toString()));
@@ -377,8 +306,8 @@ class ManagedClientJob {
      * @param resultProperties
      * @return true, if source size is larger than max size
      */
-    protected static boolean setSupportedTypeError(String inputType, final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
-        final Set<String> supportedTypes = ClientManager.get().getClientConfig().SUPPORTED_TYPES;
+    private boolean implSetSupportedTypeError(String inputType, final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
+        final Set<String> supportedTypes = m_clientManager.getClientConfig().SUPPORTED_TYPES;
         final boolean ret = (supportedTypes.size() > 0) &&
             DocumentInformation.isExtensionSupported(inputType) &&
             !supportedTypes.contains(inputType);
@@ -389,7 +318,7 @@ class ManagedClientJob {
             }
 
             if (DocumentConverterManager.isLogError()) {
-                DocumentConverterManager.logError("DC detected unsupported input file extension",
+                DocumentConverterManager.logError("DC client detected unsupported input file extension",
                     jobProperties, new LogData("inputype", inputType));
             }
         }
@@ -402,7 +331,7 @@ class ManagedClientJob {
      * @param method
      * @return
      */
-    private boolean prepareRemoteCall(HashMap<String, Object> jobProperties, String method) {
+    private boolean implPrepareRemoteCall(HashMap<String, Object> jobProperties, String method) {
         final String calledRemoteUrlString = (String) jobProperties.get(Properties.PROP_ENGINE_REMOTEURL);
         URL calledRemoteUrl = null;
         boolean ret = false;
@@ -444,9 +373,8 @@ class ManagedClientJob {
      * @param jobType
      * @return
      */
-    private Object doRemoteCall(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
+    private Object implDoRemoteCall(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties) {
         Object ret = null;
-        final HttpHelper httpHelper = HttpHelper.get();
         final boolean isMultipartRequest = (jobProperties.containsKey(Properties.PROP_INPUT_FILE) || jobProperties.containsKey(Properties.PROP_INPUT_STREAM));
         final Boolean asyncJob = (Boolean) jobProperties.get(Properties.PROP_ASYNC);
         final Boolean remoteAsyncJob = (Boolean) jobProperties.get(Properties.PROP_REMOTE_ASYNC);
@@ -454,14 +382,14 @@ class ManagedClientJob {
         final String remoteCacheHash = (String) jobProperties.get(Properties.PROP_REMOTE_CACHE_HASH);
         final boolean isAsync = ((null != asyncJob) && asyncJob.booleanValue()) || ((null != remoteAsyncJob) && remoteAsyncJob.booleanValue());
         final boolean isCacheOnly = (null != cacheOnlyJob) && cacheOnlyJob.booleanValue();
-        final String remoteParams = isMultipartRequest ? getRemoteParams(jobProperties, resultProperties, false, "returntype=binary") : getRemoteParams(jobProperties, resultProperties, true);
+        final String remoteParams = isMultipartRequest ? implGetRemoteParams(jobProperties, resultProperties, false, "returntype=binary") : implGetRemoteParams(jobProperties, resultProperties, true);
         final boolean logTrace = DocumentConverterManager.isLogTrace();
         final String remoteMethod = jobProperties.containsKey(Properties.PROP_REMOTE_METHOD) ? (String) jobProperties.get(Properties.PROP_REMOTE_METHOD) : "";
-        final String logTitle = (remoteMethod.equals("transformimage")) ?
+        final String logTitle = "transformimage".equals(remoteMethod) ?
             ("ImageServer " + (isAsync ? "asynchronous " : "") + "remote transformation") :
-                ("DC " + (isAsync ? "asynchronous " : "") + "remote conversion");
+                ("DC client " + (isAsync ? "asynchronous " : "") + "remote conversion");
 
-            if ((null != httpHelper) && (null != m_remoteUrl) && (null != remoteParams)) {
+            if ((null != m_remoteUrl) && (null != remoteParams)) {
                 final String callCookie = (String) jobProperties.get(Properties.PROP_CONVERTER_COOKIE);
                 URL remoteUrl = null;
 
@@ -482,7 +410,7 @@ class ManagedClientJob {
                         final String inputMimeType = "pdf".equals(inputType) ? "application/pdf" : "application/octet-stream";
                         final Serializable contentSerializable =  jobProperties.containsKey(Properties.PROP_INPUT_FILE) ?
                             (File) jobProperties.get(Properties.PROP_INPUT_FILE) :
-                                getInputBuffer(jobProperties, resultProperties);
+                                implGetInputBuffer(jobProperties, resultProperties);
 
 
                         if (null != contentSerializable) {
@@ -500,18 +428,15 @@ class ManagedClientJob {
                                             HttpHelper.TransferDataMode.FILE_LENGTH_AND_DATA :
                                                 HttpHelper.TransferDataMode.BYTEARRAY_OBJECT);
 
-                            httpHelper.postFormData(m_clientManager,
+                            HttpHelper.get().postFormData(
+                                m_clientManager,
                                 remoteUrl,
                                 ServerType.DOCUMENTCONVERTER,
                                 transferObject,
                                 transferDataMode,
-                                new HttpResponseProcessor() {
-
-                                @SuppressWarnings("unchecked")
-                                @Override
-                                public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
+                                (int responseCode, InputStream responseInputStream, String resultCookie) -> {
                                     // evaluate result only for synchronous calls with valid result stream
-                                    if (!isAsync && (null != responseInputStream)) {
+                                    if (!isAsync) {
                                         try (ObjectInputStream objInputStream = new ObjectInputStream(new BufferedInputStream(responseInputStream))) {
                                             final Object readObject = objInputStream.readObject();
 
@@ -535,8 +460,7 @@ class ManagedClientJob {
                                             DocumentConverterManager.logExcp(e);
                                         }
                                     }
-                                }
-                            });
+                                });
 
                             final byte[] resultBuffer = (byte[]) resultProperties.get(Properties.PROP_RESULT_BUFFER);
 
@@ -548,16 +472,14 @@ class ManagedClientJob {
                         final TransferObject<byte[]> transferObject = new TransferObject<>(remoteParams, callCookie);
                         final StringBuilder response = new StringBuilder();
 
-                        httpHelper.postRequest(m_clientManager,
+                        HttpHelper.get().postRequest(
+                            m_clientManager,
                             remoteUrl,
                             ServerType.DOCUMENTCONVERTER,
                             transferObject,
-                            new HttpResponseProcessor() {
-
-                            @Override
-                            public void processResponse(int responseCode, InputStream responseInputStream, String resultCookie) {
+                            (int responseCode, InputStream responseInputStream, String resultCookie) -> {
                                 // evaluate result only for synchronous calls with valid result stream
-                                if (!isAsync && (null != responseInputStream)) {
+                                if (!isAsync) {
                                     try (BufferedReader inputReader = new BufferedReader(new InputStreamReader(responseInputStream))) {
                                         for (String readLine = null; (readLine = inputReader.readLine()) != null;) {
                                             response.append(readLine).append('\n');
@@ -571,14 +493,12 @@ class ManagedClientJob {
                                         DocumentConverterManager.logExcp(e);
                                     }
                                 }
-                            }
-                        });
+                            });
 
-                        // parse JSON response only on case of synchronous jobs,
-                        // since we won't get a valid answer for async requests
+                        // parse JSON response only in case of synchronous jobs
                         if (!isAsync) {
                             try {
-                                ret = parseJSONResponse(new JSONObject(new JSONTokener(response.toString())), resultProperties);
+                                ret = implParseJSONResponse(new JSONObject(new JSONTokener(response.toString())), resultProperties);
                             } catch (final JSONException e) {
                                 DocumentConverterManager.logExcp(e);
                             }
@@ -612,7 +532,7 @@ class ManagedClientJob {
                 // fallback conversion or the caller is not interested in the
                 // the current result of these 'try and ignore' conversions
                 if (!isCacheOnly && !isAsync && StringUtils.isEmpty(remoteCacheHash)) {
-                    final StringBuilder errorMessageBuilder = new StringBuilder("DC received a remote conversion ");
+                    final StringBuilder errorMessageBuilder = new StringBuilder("DC client received a remote conversion ");
                     final JobError jobError = JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
 
                     DocumentConverterManager.logWarn(errorMessageBuilder.append(
@@ -635,7 +555,7 @@ class ManagedClientJob {
      * @param jobProperties
      * @return
      */
-    private String getRemoteParams(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties, boolean includeDataUrl, String... additionalParams) {
+    private String implGetRemoteParams(final HashMap<String, Object> jobProperties, final HashMap<String, Object> resultProperties, boolean includeDataUrl, String... additionalParams) {
         StringBuilder paramBuilder = new StringBuilder("action=rconvert");
         Object curParam = null;
 
@@ -800,7 +720,7 @@ class ManagedClientJob {
 
             if (includeDataUrl) {
                 // add base64 encoded data from InputFile or InputStream as data Url
-                final byte[] inputBuffer = getInputBuffer(jobProperties, resultProperties);
+                final byte[] inputBuffer = implGetInputBuffer(jobProperties, resultProperties);
 
                 if (null != inputBuffer) {
                     final String inputType = (String) jobProperties.get(Properties.PROP_INPUT_TYPE);
@@ -827,7 +747,7 @@ class ManagedClientJob {
      * @param jsonObject
      * @return
      */
-    static private Object parseJSONResponse(JSONObject jsonObject, HashMap<String, Object> resultProperties) {
+    private Object implParseJSONResponse(JSONObject jsonObject, HashMap<String, Object> resultProperties) {
         Object ret = null;
 
         try {
