@@ -58,13 +58,16 @@ import com.openexchange.ajax.container.FileHolder;
 import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
+import com.openexchange.documentconverter.DocumentConverterManager;
+import com.openexchange.documentconverter.FileIdManager;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
+import com.openexchange.documentconverter.MutableWrapper;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.PDFExtractor;
+import com.openexchange.documentconverter.client.impl.ClientConfig;
 import com.openexchange.documentconverter.client.impl.ClientManager;
-import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
@@ -80,8 +83,8 @@ class ConvertDocumentAction extends DocumentConverterAction {
      *
      * @param services
      */
-    public ConvertDocumentAction(ServiceLookup services) {
-        super(services);
+    public ConvertDocumentAction(final ServiceLookup services, final ClientManager manager, final FileIdManager fileIdManager, final ClientConfig clientConfig) {
+        super(services, manager, fileIdManager, clientConfig);
     }
 
     /*
@@ -91,26 +94,44 @@ class ConvertDocumentAction extends DocumentConverterAction {
      */
     @Override
     public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) {
+        final PDFExtractor pdfExtractor = m_manager.getPDFExtractor();
         final IDocumentConverter manager = m_services.getService(IDocumentConverter.class);
-        final File pdfExtractorExecutable = ClientManager.get().getClientConfig().PDFEXTRACTOR_EXECUTABLE_PATH;
 
-        if ((null != request)  && (null != session) && (null != manager) && (null != pdfExtractorExecutable)) {
+        if ((null != pdfExtractor) && (null != request)  && (null != session) && (null != manager)) {
             String convertAction = StringUtils.lowerCase(request.getParameter("convert_action"));
 
             if (null != convertAction) {
                 IFileHolder resultFileHolder = null;
                 JSONObject jsonResult = new JSONObject();
-                JobError jobError[] = { JobError.GENERAL };
+                final MutableWrapper<String> jobId = new MutableWrapper<>(null);
+                final MutableWrapper<JobError> jobError = new MutableWrapper<>(JobError.GENERAL);
 
-                if (convertAction.equals("beginconvert")) {
-                    performBeginConvert(request, session, manager, JobPriority.fromString(request.getParameter("convert_priority")), jsonResult, jobError);
-                } else if (convertAction.equals("getpage")) {
-                    resultFileHolder = performGetPage(request, session, manager, jsonResult, jobError);
-                } else if (convertAction.equals("endconvert")) {
-                    performEndConvert(request, session, manager, jsonResult, jobError);
+                if ("beginconvert".equals(convertAction)) {
+                    performBeginConvert(
+                        request,
+                        session,
+                        manager,
+                        JobPriority.fromString(request.getParameter("convert_priority")),
+                        jsonResult,
+                        jobId,
+                        jobError);
+                } else if ("getpage".equals(convertAction)) {
+                    resultFileHolder = performGetPage(
+                        request,
+                        session,
+                        manager,
+                        jsonResult,
+                        jobError);
+                } else if ("endconvert".equals(convertAction)) {
+                    performEndConvert(
+                        request,
+                        session,
+                        manager,
+                        jsonResult,
+                        jobError);
                 }
 
-                return getRequestResult(request, resultFileHolder, jsonResult, jobError[0]);
+                return getRequestResult(request, resultFileHolder, jsonResult, jobError.get());
             }
         }
 
@@ -125,34 +146,29 @@ class ConvertDocumentAction extends DocumentConverterAction {
      * @param jsonResult
      * @param jobError
      */
-    private void performBeginConvert(@NonNull AJAXRequestData request, @NonNull ServerSession session, @NonNull IDocumentConverter manager, @NonNull JobPriority convertPriority, @NonNull JSONObject jsonResult, @NonNull JobError[] jobError) {
-        final ManagedFile managedResultFile = getPDFFile(request, session, false, jobError);
-
-        if (null != managedResultFile) {
-            final FileIdLocker fileIdLocker = FileIdLocker.get(m_managedFileManagement);
-            final String resultFileId = managedResultFile.getID();
+    private void performBeginConvert(@NonNull AJAXRequestData request, @NonNull ServerSession session, @NonNull IDocumentConverter manager, @NonNull JobPriority convertPriority, @NonNull JSONObject jsonResult,
+        @NonNull MutableWrapper<String> jobId, @NonNull MutableWrapper<JobError> jobError) {
+        final File pdfResultFile = getPDFFile(request, session, false, jobId, jobError);
 
+        if (null != pdfResultFile) {
             try {
-                fileIdLocker.lock(resultFileId);
+                // resource is held with a configured timeout of AUTO_CLEANUP_TIMEOUT_MILLIS
+                m_fileIdManager.lock(jobId.get(), m_clientConfig.AUTO_CLEANUP_TIMEOUT_MILLIS);
 
-                final int pageCount = getPDFPageCount(managedResultFile.getFile());
+                final int pageCount = m_manager.getPDFExtractor().getPageCount(pdfResultFile);
 
                 if (pageCount > 0) {
-                    jsonResult.put("jobID", resultFileId);
+                    jsonResult.put("jobID", jobId.get());
                     jsonResult.put("pageCount", pageCount);
 
-                    fileIdLocker.holdManagedFile(resultFileId);
-                    jobError[0] = JobError.NONE;
+                    jobError.set(JobError.NONE);
                 }
             } catch (Exception e) {
-                jobError[0] = JobError.GENERAL;
-                logException(e);
+                jobError.set(JobError.GENERAL);
+                DocumentConverterManager.logExcp(e);
             } finally {
-                fileIdLocker.unlock(resultFileId);
+                m_fileIdManager.unlock(jobId.get());
             }
-
-        } else {
-            jobError[0] = JobError.GENERAL;
         }
     }
 
@@ -164,7 +180,7 @@ class ConvertDocumentAction extends DocumentConverterAction {
      * @param jobError
      * @return
      */
-    private IFileHolder performGetPage(@NonNull AJAXRequestData request, @NonNull ServerSession session, @NonNull IDocumentConverter manager, @NonNull JSONObject jsonResult, @NonNull JobError[] jobError) {
+    private IFileHolder performGetPage(@NonNull AJAXRequestData request, @NonNull ServerSession session, @NonNull IDocumentConverter manager, @NonNull JSONObject jsonResult, @NonNull MutableWrapper<JobError> jobError) {
         IFileHolder resultFileHolder = null;
         final String jobIdStr = request.getParameter("job_id");
         final String targetFormat = request.getParameter("target_format");
@@ -172,31 +188,31 @@ class ConvertDocumentAction extends DocumentConverterAction {
         final int pageNumber = (null != pageNumberStr) ? Integer.parseInt(pageNumberStr) : 0;
         final boolean isPngTarget = "png".equalsIgnoreCase(targetFormat);
         final boolean isJpegTarget = !isPngTarget && ("jpg".equalsIgnoreCase(targetFormat) || "jpeg".equalsIgnoreCase(targetFormat));
+        final boolean isSVGTarget = !isPngTarget && !isJpegTarget && "svg".equalsIgnoreCase(targetFormat);
 
-        if ((null != jobIdStr) && (pageNumber > 0) && (isPngTarget || isJpegTarget)) {
-            final FileIdLocker fileIdLocker = FileIdLocker.get(m_managedFileManagement);
+        jobError.set(JobError.GENERAL);
+
+        if (StringUtils.isNotBlank(jobIdStr) && (pageNumber > 0) && (isPngTarget || isJpegTarget|| isSVGTarget)) {
             File tmpOutputFile = null;
 
             try {
-                fileIdLocker.lock(jobIdStr);
+                m_fileIdManager.lock(jobIdStr);
 
-                final PDFExtractor pdfExtractor = getPDFExtractor();
-                final ManagedFile pdfInputFile = getManagedFile(jobIdStr);
+                final File pdfInputFile = m_fileIdManager.getDataFile(jobIdStr);
 
                 if (null == pdfInputFile) {
-                    logException(new RuntimeException("DC Ajax handler got no managed file for PDF document: " + jobIdStr));
-                }
-
-                if (null != pdfExtractor) {
+                    DocumentConverterManager.logError("DC client Ajax #getPage handler got no input file for PDF document. The input file has been removed by auto cleanup handler in the meantime: " + jobIdStr);
+                    jobError.set(JobError.NO_CONTENT);
+                } else {
                     final String targetWidthStr = request.getParameter("target_width");
                     final String targetHeightStr = request.getParameter("target_height");
                     final int pixelWidth = new Integer((null != targetWidthStr) ? targetWidthStr : "-1").intValue();
                     final int pixelHeight = new Integer((null != targetHeightStr) ? targetHeightStr : "-1").intValue();
 
-                    tmpOutputFile = File.createTempFile(jobIdStr, ".tmp", pdfExtractor.getWorkDir());
+                    tmpOutputFile = m_manager.createTempFile(jobIdStr);
 
-                    pdfExtractor.extractToGraphic(
-                        pdfInputFile.getFile(),
+                    m_manager.getPDFExtractor().extractToGraphic(
+                        pdfInputFile,
                         tmpOutputFile,
                         targetFormat,
                         pageNumber,
@@ -208,23 +224,22 @@ class ConvertDocumentAction extends DocumentConverterAction {
                     resultFileHolder = new FileHolder(
                         new ByteArrayInputStreamClosure(FileUtils.readFileToByteArray(tmpOutputFile)),
                             tmpOutputFile.length(),
-                            isPngTarget ? "image/png" : "image/jpeg",
+                            isPngTarget ? "image/png" : (isSVGTarget ? "image/svg+xml" : "image/jpeg"),
                             new StringBuilder(32).append("pdfpage_").
                                 append(pageNumber).
-                                append(isPngTarget ? ".png" : ".jpg").toString());
+                                append(isPngTarget ? ".png" : (isSVGTarget ? ".svg" : ".jpg")).toString());
 
                     request.setFormat("file");
                     request.setProperty("target_width", Integer.valueOf(pixelWidth));
                     request.setProperty("target_height", Integer.valueOf(pixelHeight));
 
-                    jobError[0] = JobError.NONE;
+                    jobError.set(JobError.NONE);
                 }
             } catch (Exception e) {
-                jobError[0] = JobError.GENERAL;
-                logException(e);
+                DocumentConverterManager.logExcp(e);
             } finally {
                 FileUtils.deleteQuietly(tmpOutputFile);
-                fileIdLocker.unlock(jobIdStr);
+                m_fileIdManager.unlock(jobIdStr);
             }
         }
 
@@ -238,21 +253,19 @@ class ConvertDocumentAction extends DocumentConverterAction {
      * @param jsonResult
      * @param jobError
      */
-    private void performEndConvert(@NonNull AJAXRequestData request, @NonNull ServerSession session, @NonNull IDocumentConverter manager, @NonNull JSONObject jsonResult, @NonNull JobError[] jobError) {
+    private void performEndConvert(@NonNull AJAXRequestData request, @NonNull ServerSession session, @NonNull IDocumentConverter manager, @NonNull JSONObject jsonResult, @NonNull MutableWrapper<JobError> jobError) {
         final String jobIdStr = request.getParameter("job_id");
 
         if (StringUtils.isNotBlank(jobIdStr)) {
-            final FileIdLocker fileIdLocker = FileIdLocker.get(m_managedFileManagement);
-
             try {
-                fileIdLocker.lock(jobIdStr);
-                fileIdLocker.unholdManagedFile(jobIdStr);
+                m_fileIdManager.lock(jobIdStr);
+                m_fileIdManager.delete(jobIdStr);
             } finally {
-                fileIdLocker.unlock(jobIdStr);
-                jobError[0] = JobError.NONE;
+                jobError.set(JobError.NONE);
+                m_fileIdManager.unlock(jobIdStr);
             }
         } else {
-            jobError[0] = JobError.NO_CONTENT;
+            jobError.set(JobError.NO_CONTENT);
         }
     }
 }
