@@ -49,33 +49,31 @@
 package com.openexchange.documentconverter.client.json;
 
 import java.io.File;
-import java.io.IOException;
 import java.io.InputStream;
 import java.util.EnumSet;
 import java.util.HashMap;
+import java.util.UUID;
+import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.crypto.CryptographicServiceAuthenticationFactory;
-import com.openexchange.config.ConfigurationService;
+import com.openexchange.documentconverter.DocumentConverterManager;
+import com.openexchange.documentconverter.FileIdManager;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
+import com.openexchange.documentconverter.MutableWrapper;
 import com.openexchange.documentconverter.NonNull;
-import com.openexchange.documentconverter.Nullable;
-import com.openexchange.documentconverter.PDFExtractor;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.documentconverter.client.impl.ClientConfig;
 import com.openexchange.documentconverter.client.impl.ClientManager;
-import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.FileStorageCapability;
 import com.openexchange.file.storage.FileStorageFileAccess;
 import com.openexchange.file.storage.composition.FolderID;
@@ -83,11 +81,12 @@ import com.openexchange.file.storage.composition.IDBasedFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographicAwareIDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographyMode;
-import com.openexchange.filemanagement.ManagedFile;
-import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.groupware.attach.Attachments;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.mail.MailServletInterface;
+import com.openexchange.mail.compose.Attachment;
+import com.openexchange.mail.compose.CompositionSpaceService;
+import com.openexchange.mail.compose.CompositionSpaces;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
@@ -112,26 +111,13 @@ public abstract class DocumentConverterAction implements AJAXActionService {
      *
      * @param services
      */
-    public DocumentConverterAction(ServiceLookup services) {
+    public DocumentConverterAction(final ServiceLookup services, final ClientManager manager, final FileIdManager fileIdManager, final ClientConfig clientConfig) {
         super();
 
         m_services = services;
-
-        if (null != m_services) {
-            final ConfigurationService configService = m_services.getService(ConfigurationService.class);
-
-            // read some config entries
-            if (null != configService) {
-                final int curIntEntry = configService.getIntProperty("com.openexchange.documentconverter.maxSourceFileSizeMB", Integer.MIN_VALUE);
-
-                // ENGINE_MAX_SOURCEFILESIZE_MB
-                if (curIntEntry != Integer.MIN_VALUE) {
-                    m_maxSourceFileSizeMB = curIntEntry;
-                }
-            }
-
-            m_managedFileManagement = m_services.getService(ManagedFileManagement.class);
-        }
+        m_manager = manager;
+        m_fileIdManager = fileIdManager;
+        m_clientConfig = clientConfig;
     }
 
     /**
@@ -140,17 +126,17 @@ public abstract class DocumentConverterAction implements AJAXActionService {
      * @param jobError
      * @return
      */
-    protected ManagedFile getRequestSourceFile(@NonNull final AJAXRequestData request, final @NonNull ServerSession session, @NonNull JobError[] jobError) {
-        final FileIdLocker fileIdLocker = FileIdLocker.get(m_managedFileManagement);
+    protected File getRequestSourceFile(@NonNull final AJAXRequestData request, @NonNull final ServerSession session, @NonNull final MutableWrapper<JobError> jobError) {
         final String documentId = getDocumentId(request);
 
-        ManagedFile ret = null;
+        File ret = null;
 
         try {
-            fileIdLocker.lock(documentId);
+            m_fileIdManager.lock(documentId);
 
-            if (null == (ret = getManagedFile(documentId))) {
+            if (null == (ret = m_fileIdManager.getDataFile(documentId))) {
                 final String fileId = request.getParameter("id");
+                final String attachmentId = request.getParameter("attachmentId");
                 final String source = request.getParameter("source");
                 final String attached = request.getParameter("attached");
                 final String module = request.getParameter("module");
@@ -159,6 +145,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                 final String cryptoAuth = request.getParameter("cryptoAuth");
                 final boolean mailCheck = ((attached != null) && (folderId != null) && (attached.length() > 0));
                 final boolean taskCheck = mailCheck && (module != null);
+                final boolean composeCheck = (fileId != null) && (attachmentId != null);
                 MailServletInterface mailServletInterface = null; // closing done in finally block
                 InputStream documentStm = null; // closing done in finally block
 
@@ -187,6 +174,17 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                                 documentStm = mailPart.getInputStream();
                             }
                         }
+                    } else if (composeCheck && "compose".equals(source)) {
+                        // Composition space attachment
+                        CompositionSpaceService compositionSpaceService = m_services.getOptionalService(CompositionSpaceService.class);
+                        if (compositionSpaceService == null) {
+                            jobError.set(JobError.GENERAL);
+                        } else {
+                            UUID compositionSpaceUuid = CompositionSpaces.parseCompositionSpaceId(fileId);
+                            UUID attachmentUuid = CompositionSpaces.parseAttachmentId(attachmentId);
+                            Attachment attachment = compositionSpaceService.getAttachment(compositionSpaceUuid, attachmentUuid, session);
+                            documentStm = attachment.getData();
+                        }
                     } else if (taskCheck && ("tasks".equals(source) || "calendar".equals(source) || "contacts".equals(source))) {
                         // other attachment from tasks, calendar or contact
 
@@ -225,8 +223,8 @@ public abstract class DocumentConverterAction implements AJAXActionService {
 
                             // set output paramter jobError to JobError.PASSWORD in
                             // case we got no valid fileAccess for given Guard parameters
-                            if ((null == fileAccess) && (jobError.length > 0)) {
-                                jobError[0] = JobError.PASSWORD;
+                            if (null == fileAccess) {
+                                jobError.set(JobError.PASSWORD);
                             }
                         }
 
@@ -248,10 +246,10 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                     }
 
                     if (null != documentStm) {
-                        ret = m_managedFileManagement.createManagedFile(documentId, documentStm);
+                        ret = m_fileIdManager.setDataInputStream(documentId, documentStm);
                     }
                 } catch (final Exception e) {
-                    logException(e);
+                    DocumentConverterManager.logExcp(e);
                 } finally {
                     IOUtils.closeQuietly(documentStm);
                     if (mailServletInterface != null) {
@@ -260,7 +258,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                 }
             }
         } finally {
-            fileIdLocker.unlock(documentId);
+            m_fileIdManager.unlock(documentId);
         }
 
         return ret;
@@ -273,33 +271,40 @@ public abstract class DocumentConverterAction implements AJAXActionService {
      * @param resultJobError
      * @return
      */
-    protected ManagedFile getPDFFile(@NonNull AJAXRequestData request, @NonNull ServerSession session, boolean isAsync, final JobError[] resultJobError) {
-        final FileIdLocker fileIdLocker = FileIdLocker.get(m_managedFileManagement);
+    protected File getPDFFile(@NonNull AJAXRequestData request, @NonNull ServerSession session, boolean isAsync,
+        final MutableWrapper<String> resultJobId, final MutableWrapper<JobError> resultJobError) {
+
         final IDocumentConverter docConverter = m_services.getService(IDocumentConverter.class);
-        ManagedFile managedResultFile = null;
+        File resultFile = null;
+
+        resultJobError.set(JobError.GENERAL);
 
         if (null != docConverter) {
             final String locale = getPreferredLanguage(session);
-            final String resultDocumentId = getDocumentId(request, "pdf", locale);
+
+            resultJobId.set(getDocumentId(request, "pdf", locale));
 
             try {
-                fileIdLocker.lock(resultDocumentId);
+                m_fileIdManager.lock(resultJobId.get());
 
-                if (null == (managedResultFile = getManagedFile(resultDocumentId))) {
-                    final ManagedFile managedSourceFile = getRequestSourceFile(request, session, resultJobError);
+                if (null == (resultFile = m_fileIdManager.getDataFile(resultJobId.get()))) {
+                    final File sourceFile = getRequestSourceFile(request, session, resultJobError);
 
-                    if(null != managedSourceFile) {
+                    if(null != sourceFile) {
                         final String fileName = request.getParameter("filename");
 
                         if ((null != fileName) && "pdf".equalsIgnoreCase(FilenameUtils.getExtension(fileName))) {
                             // return source file in case of a PDF source
-                            managedResultFile = managedSourceFile;
+                            try (final InputStream srcInputStm = FileUtils.openInputStream(sourceFile)) {
+                                resultFile = m_fileIdManager.setDataInputStream(resultJobId.get(), srcInputStm);
+                                resultJobError.set(JobError.NONE);
+                            }
                         } else {
                             // convert to PDF
                             final HashMap<String, Object> jobProperties = new HashMap<>(12);
                             final HashMap<String, Object> resultProperties = new HashMap<>(8);
 
-                            jobProperties.put(Properties.PROP_INPUT_FILE, managedSourceFile.getFile());
+                            jobProperties.put(Properties.PROP_INPUT_FILE, sourceFile);
                             jobProperties.put(Properties.PROP_PRIORITY, JobPriority.fromString(request.getParameter("priority")));
                             jobProperties.put(Properties.PROP_LOCALE, locale);
 
@@ -317,28 +322,28 @@ public abstract class DocumentConverterAction implements AJAXActionService {
 
                             try (InputStream pdfResultStm = docConverter.convert("pdf", jobProperties, resultProperties)) {
                                 if (null != pdfResultStm) {
-                                    managedResultFile = m_managedFileManagement.createManagedFile(resultDocumentId, pdfResultStm);
-                                    resultJobError[0] = JobError.NONE;
+                                    resultFile = m_fileIdManager.setDataInputStream(resultJobId.get(), pdfResultStm);
+                                    resultJobError.set(JobError.NONE);
                                 } else {
-                                    resultJobError[0] = isAsync ? JobError.NONE : JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
+                                    resultJobError.set(isAsync ? JobError.NONE : JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)));
                                 }
                             }
                         }
                     } else {
                         // async case for PDF documents
-                        resultJobError[0] = isAsync ? JobError.NONE : JobError.NO_CONTENT;
+                        resultJobError.set(isAsync ? JobError.NONE : JobError.NO_CONTENT);
                     }
+                } else {
+                    resultJobError.set(JobError.NONE);
                 }
             } catch (Exception e) {
-                logException(e);
+                DocumentConverterManager.logExcp(e);
             } finally {
-                fileIdLocker.unlock(resultDocumentId);
+                m_fileIdManager.unlock(resultJobId.get());
             }
-        } else {
-            resultJobError[0] = JobError.GENERAL;
         }
 
-        return managedResultFile;
+        return resultFile;
     }
 
     /**
@@ -380,7 +385,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
 
                     case MAX_SOURCESIZE: {
                         errorCause = "maxSourceSizeExceeded";
-                        jsonResult.put("MaxSourceSizeMB", "" + m_maxSourceFileSizeMB);
+                        jsonResult.put("MaxSourceSizeMB", "" + (m_clientConfig.MAX_DOCUMENT_SOURCEFILESIZE / 1024) / 1024);
                         break;
                     }
 
@@ -420,7 +425,7 @@ public abstract class DocumentConverterAction implements AJAXActionService {
                     jsonResult.put("cause", errorCause);
                 }
             } catch (final JSONException e) {
-                logException(e);
+                DocumentConverterManager.logExcp(e);
             }
 
             request.setFormat("json");
@@ -430,36 +435,11 @@ public abstract class DocumentConverterAction implements AJAXActionService {
         return ret;
     }
 
-    /**
-     * @return
-     * @throws IOException
-     */
-    protected @Nullable PDFExtractor getPDFExtractor() throws IOException {
-        final ClientConfig clientConfig = ClientManager.get().getClientConfig();
-        final File pdfExtractorExecutable = clientConfig.PDFEXTRACTOR_EXECUTABLE_PATH;
-
-        return (null != pdfExtractorExecutable) ?
-            PDFExtractor.get(pdfExtractorExecutable, clientConfig.PDFEXTRACTOR_WORKDIR) :
-                null;
-    }
-
-    /**
-     * @param pdfInputFile
-     * @return
-     */
-    protected int getPDFPageCount(@NonNull final File pdfInputFile) throws IOException {
-        final PDFExtractor pdfExtractor = getPDFExtractor();
-
-        return (null != pdfExtractor) ?
-            pdfExtractor.getPageCount(pdfInputFile) :
-                -1;
-    }
-
     /**
      * @param session
      * @return
      */
-    protected @NonNull String getPreferredLanguage(ServerSession session) {
+    protected static @NonNull String getPreferredLanguage(ServerSession session) {
         final User sessionUser = session.getUser();
         String prefLanguage = null;
 
@@ -475,68 +455,29 @@ public abstract class DocumentConverterAction implements AJAXActionService {
      * @param request
      * @return
      */
-    protected String getDocumentId(@NonNull AJAXRequestData request, String... additionalData) {
-        final StringBuilder idBuilder = new StringBuilder(128);
-        final String[][] allParamArrays = { idParamArray, additionalData };
+    protected static @NonNull String getDocumentId(@NonNull AJAXRequestData request, String... additionalData) {
+        final StringBuilder documentIdBuilder = new StringBuilder(256);
 
-        for (final String[] curParamArray : allParamArrays) {
+        for (final String[] curParamArray : new String[][] { idParamArray, additionalData }) {
             if (null != curParamArray) {
                 final boolean isParam = curParamArray.equals(idParamArray);
 
-                for (final String curParam : curParamArray) {
-                    String curValue = curParam;
-
-                    if (isParam) {
-                        curValue = request.getParameter(curParam);
-                    }
-
-                    idBuilder.append(curValue).append('#');
+                for (final String curValue : curParamArray) {
+                    documentIdBuilder.append(isParam ? request.getParameter(curValue) : curValue).append('~');
                 }
             }
         }
 
-        return idBuilder.toString();
-    }
-
-    /**
-     * @param id
-     * @return
-     */
-    @Nullable protected ManagedFile getManagedFile(@NonNull final String id) {
-        ManagedFile ret = null;
-
-        try {
-            ret = m_managedFileManagement.optByID(id);
-
-            // TODO: clarify with Thorben, why this size check seems to be necessary nowadays
-            if ((null != ret) && (ret.getSize() <= 0)) {
-                ret.delete();
-                ret = null;
-            }
-        } catch (final OXException e) {
-            logException(e);
-        }
-
-        return ret;
-    }
-
-
-    /**
-     * @param e
-     */
-    protected void logException(Exception e) {
-        if (null != LOG) {
-            LOG.error(((null != e) && (null != e.getMessage())) ? e.getMessage() : "Unknown exception occured");
-        }
+        return documentIdBuilder.toString();
     }
 
     // - Members ---------------------------------------------------------------
 
-    private Logger LOG = LoggerFactory.getLogger(this.getClass());
+    final protected ServiceLookup m_services;
 
-    protected ServiceLookup m_services = null;
+    final protected ClientManager m_manager;
 
-    protected ManagedFileManagement m_managedFileManagement = null;
+    final protected ClientConfig m_clientConfig;
 
-    protected long m_maxSourceFileSizeMB = 32;
+    final protected FileIdManager m_fileIdManager;
 }
