@@ -64,11 +64,15 @@ import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.DispatcherNotes;
 import com.openexchange.documentconverter.DocumentConverterManager;
+import com.openexchange.documentconverter.FileIdManager;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
+import com.openexchange.documentconverter.MutableWrapper;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.Properties;
+import com.openexchange.documentconverter.client.impl.ClientConfig;
+import com.openexchange.documentconverter.client.impl.ClientManager;
 import com.openexchange.file.storage.DefaultFile;
 import com.openexchange.file.storage.File.Field;
 import com.openexchange.file.storage.FileStorageFileAccess;
@@ -78,7 +82,6 @@ import com.openexchange.file.storage.composition.IDBasedFileAccess;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.IDBasedFolderAccess;
 import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
-import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
@@ -101,8 +104,8 @@ public class GetDocumentAction extends DocumentConverterAction {
      *
      * @param services
      */
-    public GetDocumentAction(ServiceLookup services) {
-        super(services);
+    public GetDocumentAction(final ServiceLookup services, final ClientManager manager, final FileIdManager fileIdManager, ClientConfig clientConfig) {
+        super(services, manager, fileIdManager, clientConfig);
     }
 
     /* (non-Javadoc)
@@ -115,24 +118,25 @@ public class GetDocumentAction extends DocumentConverterAction {
         final String async = request.getParameter("async");
         final boolean convertToPDF = "pdf".equalsIgnoreCase(request.getParameter("documentformat")) && !"application/pdf".equalsIgnoreCase(mimeType);
         final boolean isAsync = (null != async) && async.equalsIgnoreCase("true");
-        final JobError[] jobError = { JobError.NONE };
-        ManagedFile managedResultFile = null;
+        final MutableWrapper<String> jobId = new MutableWrapper<>(null);
+        final MutableWrapper<JobError> jobError = new MutableWrapper<>(JobError.NONE);
+        File resultFile = null;
 
-        if ((!convertToPDF || (null == (managedResultFile = getPDFFile(request, session, isAsync, jobError)))) && !isAsync) {
+        if ((!convertToPDF || (null == (resultFile = getPDFFile(request, session, isAsync, jobId, jobError)))) && !isAsync) {
             final IDocumentConverter docConverter = m_services.getService(IDocumentConverter.class);
             final String encTest = request.getParameter("enctest");
 
             // In case of PDF input and output, the result file is equal to the source file
-            managedResultFile = getRequestSourceFile(request, session, jobError);
+            resultFile = getRequestSourceFile(request, session, jobError);
 
             // If source file is valid and encTest is set to 'pdf',
             // do an encryption test to get a valid error code in
             // case of an encrypted PDF
-            if ((null != managedResultFile) && (null != encTest) && encTest.equalsIgnoreCase("pdf") && (null != docConverter)) {
+            if ((null != resultFile) && (null != encTest) && encTest.equalsIgnoreCase("pdf") && (null != docConverter)) {
                 final HashMap<String, Object> jobProperties = new HashMap<>(12);
                 final HashMap<String, Object> resultProperties = new HashMap<>(8);
 
-                jobProperties.put(Properties.PROP_INPUT_FILE, managedResultFile.getFile());
+                jobProperties.put(Properties.PROP_INPUT_FILE, resultFile);
                 jobProperties.put(Properties.PROP_PRIORITY, JobPriority.fromString(request.getParameter("priority")));
 
                 if (null != fileName) {
@@ -142,24 +146,28 @@ public class GetDocumentAction extends DocumentConverterAction {
                 // do the PDF encryption test and close possible result stream immediately
                 IOUtils.closeQuietly(docConverter.convert("pdfenctest", jobProperties, resultProperties));
 
-                jobError[0] = isAsync ?
+                jobError.set(isAsync ?
                     JobError.NONE :
-                        JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE));
+                        JobError.fromObject(resultProperties.get(Properties.PROP_RESULT_ERROR_CODE)));
             }
         }
 
         // create appropriate response result
+        final String resultFileId = jobId.get();
         IFileHolder resultFileHolder = null;
         JSONObject jsonResult = null;
 
         try {
+            if (null != resultFileId) {
+                m_fileIdManager.lock(resultFileId);
+            }
+
             if (isAsync) {
                 (jsonResult = new JSONObject()).put("async", true);
-            } else if (null != managedResultFile) {
+            } else if (null != resultFile) {
                 final String sessionId = request.getParameter("session");
                 final String saveAsFileName = request.getParameter("saveas_filename");
                 final String saveAsFolderId = request.getParameter("saveas_folder_id");
-                final File tempFile = managedResultFile.getFile();
 
                 if (StringUtils.isBlank(fileName) || !"pdf".equalsIgnoreCase(FilenameUtils.getExtension(fileName))) {
                     final StringBuilder fileNameBuilder = new StringBuilder(StringUtils.isBlank(fileName) ? "file" : fileName);
@@ -172,19 +180,23 @@ public class GetDocumentAction extends DocumentConverterAction {
                                         fileNameBuilder.append(".pdf")).toString();
                 }
 
-                jsonResult = getJSONResultForSaveAs(session, sessionId, tempFile, saveAsFileName, saveAsFolderId, fileName, mimeType);
+                jsonResult = getJSONResultForSaveAs(session, sessionId, resultFile, saveAsFileName, saveAsFolderId, fileName, mimeType);
 
                 if (null == jsonResult) {
-                    resultFileHolder = new FileHolder(FileHolder.newClosureFor(tempFile), tempFile.length(), mimeType, fileName);
+                    resultFileHolder = new FileHolder(FileHolder.newClosureFor(resultFile), resultFile.length(), mimeType, fileName);
                 } else if (jsonResult.getInt(KEY_ERRORCODE) > ERRORCODE_NONE) {
                     return (new AJAXRequestResult().setHttpStatusCode(ERRORCODE_BAD_REQUEST));
                 }
             }
         } catch (Exception e) {
-            logException(e);
+            DocumentConverterManager.logExcp(e);
+        } finally {
+            if (null != resultFileId) {
+                m_fileIdManager.unlock(resultFileId);
+            }
         }
 
-        return getRequestResult(request, resultFileHolder, jsonResult, jobError[0]);
+        return getRequestResult(request, resultFileHolder, jsonResult, jobError.get());
     }
 
     /**
@@ -205,7 +217,7 @@ public class GetDocumentAction extends DocumentConverterAction {
             // #60025: we need to check for an illegal CSRF attempt by checking the
             // correct sessionId; set errorcode to 400 in case of an invalid request
             if ((null == sessionId) || !sessionId.equals(session.getSessionID())) {
-                DocumentConverterManager.logError("DC Ajax handler was called with invalid sessionId for save request: " + sessionId);
+                DocumentConverterManager.logError("DC client Ajax handler was called with invalid sessionId for save request: " + sessionId);
                 ret = (new JSONObject()).put(KEY_ERRORCODE, ERRORCODE_BAD_REQUEST);
             } else {
                 final IDBasedFolderAccessFactory folderFactory = m_services.getService(IDBasedFolderAccessFactory.class);
