@@ -56,6 +56,7 @@ import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
+import com.openexchange.documentconverter.FileIdManager;
 import com.openexchange.documentconverter.HttpHelper;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.client.impl.ClientConfig;
@@ -65,9 +66,9 @@ import com.openexchange.documentconverter.client.preview.DocumentConverterPrevie
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
 import com.openexchange.file.storage.composition.crypto.CryptographicAwareIDBasedFileAccessFactory;
-import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.guard.api.GuardApi;
 import com.openexchange.imagetransformation.ImageTransformationService;
+import com.openexchange.mail.compose.CompositionSpaceService;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.preview.InternalPreviewService;
 
@@ -89,7 +90,6 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
             CapabilityService.class,
             IDBasedFolderAccessFactory.class,
             IDBasedFileAccessFactory.class,
-            ManagedFileManagement.class,
             SSLSocketFactoryProvider.class
         };
     }
@@ -120,13 +120,17 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
         final ConfigurationService configService = getService(ConfigurationService.class);
 
         if (null != configService) {
+            final ClientConfig clientConfig = new ClientConfig(configService);
+
             // initialize HttpHelper singleton with SSL socket factory provider
             HttpHelper.newInstance(getService(SSLSocketFactoryProvider.class));
 
-
-            final ClientConfig clientConfig = new ClientConfig(configService);
+            // initialize ClientManager singleton
             final ClientManager clientManager = ClientManager.newInstance(this, clientConfig);
 
+            // initialize FileIdDataManager singleton
+            final FileIdManager fileIdManager = FileIdManager.newInstance(clientManager, clientConfig.AUTO_CLEANUP_TIMEOUT_MILLIS);
+
             LOG.info("Registering DocumentConverter services");
             registerService(IDocumentConverter.class, clientManager, null);
             registerService(Reloadable.class, clientManager);
@@ -136,9 +140,10 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
             registerService(InternalPreviewService.class, new DocumentConverterPreviewService(this));
 
             // register DocumentConverter related Ajax handlers
-            registerModule(new DocumentConverterActionFactory(this), "oxodocumentconverter");
+            registerModule(new DocumentConverterActionFactory(this, clientManager, fileIdManager, clientConfig), "oxodocumentconverter");
 
             // register information bean if/when ManagementService is available
+            trackService(CompositionSpaceService.class);
             openTrackers();
         }
     }
@@ -148,6 +153,13 @@ public class DocumentConverterClientActivator extends AJAXModuleActivator {
      */
     @Override
     protected void stopBundle() throws Exception {
+        // shutdown FileIdDataManager singleton
+        final FileIdManager fileIdManager = FileIdManager.get();
+
+        if (null != fileIdManager) {
+            fileIdManager.shutdown();
+        }
+
         FileUtils.deleteQuietly(ClientManager.get().getClientConfig().PDFEXTRACTOR_WORKDIR);
         super.stopBundle();
     }
