@@ -74,10 +74,10 @@ import org.apache.poi.util.IOUtils;
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.conversion.Data;
 import com.openexchange.conversion.DataProperties;
+import com.openexchange.documentconverter.DocumentConverterManager;
 import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.JobError;
 import com.openexchange.documentconverter.JobPriority;
-import com.openexchange.documentconverter.DocumentConverterManager;
 import com.openexchange.documentconverter.NonNull;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.documentconverter.client.impl.ClientManager;
@@ -164,7 +164,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
                     final String fileInputType = getInputType(fileMimeType, fileName, documentFile);
 
 
-                    if (!fileInputType.equals("pdf")) {
+                    if (!"pdf".equals(fileInputType)) {
                         final String previewLanguage = detectPreviewLanguage(dataProperties.get("PreviewLanguage"), session);
                         final HashMap<String, Object> jobProperties = new HashMap<>(12);
                         final HashMap<String, Object> resultProperties = new HashMap<>(8);
@@ -212,7 +212,6 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
      * com.openexchange.session.Session, int)
      */
     @Override
-    @Deprecated
     public PreviewDocument getPreviewFor(String arg, PreviewOutput output, Session session, int pages) {
         return new DocumentConverterPreviewDocument(null, null, null, Boolean.FALSE);
     }
@@ -404,7 +403,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
                     // images with the proper mime tye are finally
                     // scaled to the proper thumbnail destination size
-                    if ((fastPreviewResult.m_mimeType.equals("image/jpeg") || fastPreviewResult.m_mimeType.equals("image/png")) &&
+                    if (("image/jpeg".equals(fastPreviewResult.m_mimeType) || "image/png".equals(fastPreviewResult.m_mimeType)) &&
                         ((previewWidth > 0) || (previewHeight > 0))) {
 
                         ImageTransformationService imageScalingService = m_serviceLookup.getService(ImageTransformationService.class);
@@ -702,7 +701,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
     final protected static void handleExcp(Exception e) throws OXException {
         if (null != e) {
             if (e instanceof org.apache.poi.poifs.filesystem.OfficeXmlFileException) {
-                DocumentConverterManager.logInfo("DC document ambiguity: cannot read binary document format with XML extension.");
+                DocumentConverterManager.logInfo("DC OfficePreviewService document ambiguity: cannot read binary document format with XML extension.");
             } else if (e instanceof IOException) {
                 throw PreviewExceptionCodes.IO_ERROR.create(e, e.getMessage());
             } else if (e instanceof RuntimeException) {
@@ -718,7 +717,7 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
         final InputStream inputStm = documentData.getData();
         File ret = null;
 
-        if ((null != inputStm) && (null != (ret = DocumentConverterManager.createTempFile(FileUtils.getTempDirectoryPath(), "oxpreview", null)))) {
+        if ((null != inputStm) && (null != (ret = ClientManager.get().createTempFile("oxpreview")))) {
             try {
                 FileUtils.copyInputStreamToFile(inputStm, ret);
             } catch (IOException e) {
@@ -759,11 +758,11 @@ public class DocumentConverterPreviewService implements RemoteInternalPreviewSer
 
         // other types are checked based on the given mimetype and/or extension
         if (null == ret) {
-            if (fileMimeType.equals("image/png") || extension.equals("pdf")) {
+            if ("image/png".equals(fileMimeType) || "pdf".equals(extension)) {
                 ret = "png";
-            } else if (fileMimeType.equals("image/jpeg") || extension.equals("jpg") || extension.equals("jpeg")) {
+            } else if ("image/jpeg".equals(fileMimeType) || "jpg".equals(extension) || "jpeg".equals(extension)) {
                 ret = "jpg";
-            } else if (fileMimeType.equals("image/svg+xml") || extension.equals("svg")) {
+            } else if ("image/svg+xml".equals(fileMimeType) || "svg".equals(extension)) {
                 ret = "svg";
             } else if (extension.length() > 0) {
                 ret = extension;
